pub struct Node {
pub id: NodeId,
pub component: ComponentRef,
pub input: InputMapping,
pub output: OutputMapping,
pub err_map: Option<OutputMapping>,
pub routing: Routing,
pub telemetry: TelemetryHints,
}Expand description
Flow node representation.
Fields
id: NodeIdNode identifier.
component: ComponentRefComponent binding referenced by the node.
input: InputMappingComponent input mapping configuration.
output: OutputMappingComponent output mapping configuration.
err_map: Option<OutputMapping>Optional error mapping configuration.
routing: RoutingRouting behaviour after this node.
telemetry: TelemetryHintsOptional telemetry hints for this node.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn in_map(&self) -> &InputMapping
pub fn in_map(&self) -> &InputMapping
Returns the canonical input mapping surface.
Sourcepub fn out_map(&self) -> &OutputMapping
pub fn out_map(&self) -> &OutputMapping
Returns the canonical output mapping surface.
Sourcepub fn err_map(&self) -> Option<&OutputMapping>
pub fn err_map(&self) -> Option<&OutputMapping>
Returns the canonical error mapping surface when configured.
Sourcepub fn is_builtin(&self) -> bool
pub fn is_builtin(&self) -> bool
Whether this node is a runner builtin (engine-handled, resolving to no
pack component): dw.agent[.<id>], dw.agent_graph[.<id>],
sorla.call, operala.call, agentic.call, session.wait,
flow.call, provider.invoke, emit.*.
A dw.agent.<id> (and other dispatch) node compiles to the generic
component.exec placeholder with the real kind in operation, so the
operation is authoritative when the component id is empty/component.exec.